@@ -5,9 +5,20 @@
 import os
 import random
 import string
+from functools import partial
 from logging import getLogger
 from tempfile import TemporaryDirectory
-from typing import TYPE_CHECKING, Iterable, Iterator, Optional, Sequence, Tuple, TypeVar, Union
+from typing import (
+    TYPE_CHECKING,
+    Callable,
+    Iterable,
+    Iterator,
+    Optional,
+    Sequence,
+    Tuple,
+    TypeVar,
+    Union,
+)
 
 from snowflake.connector import ProgrammingError
 from snowflake.connector.options import pandas
@@ -20,7 +31,7 @@ if TYPE_CHECKING:  # pragma: no cover
     except ImportError:
         sqlalchemy = None
 
-T = TypeVar('T', bound=Sequence)
+T = TypeVar("T", bound=Sequence)
 
 logger = getLogger(__name__)
 
@@ -28,22 +39,39 @@ logger = getLogger(__name__)
 def chunk_helper(lst: T, n: int) -> Iterator[Tuple[int, T]]:
     """Helper generator to chunk a sequence efficiently with current index like if enumerate was called on sequence."""
     for i in range(0, len(lst), n):
-        yield int(i / n), lst[i:i + n]
+        yield int(i / n), lst[i : i + n]
 
 
-def write_pandas(conn: 'SnowflakeConnection',
-                 df: 'pandas.DataFrame',
-                 table_name: str,
-                 database: Optional[str] = None,
-                 schema: Optional[str] = None,
-                 chunk_size: Optional[int] = None,
-                 compression: str = 'gzip',
-                 on_error: str = 'abort_statement',
-                 parallel: int = 4,
-                 quote_identifiers: bool = True
-                 ) -> Tuple[bool, int, int,
-                            Sequence[Tuple[str, str, int, int, int, int, Optional[str], Optional[int],
-                                           Optional[int], Optional[str]]]]:
+def write_pandas(
+    conn: "SnowflakeConnection",
+    df: "pandas.DataFrame",
+    table_name: str,
+    database: Optional[str] = None,
+    schema: Optional[str] = None,
+    chunk_size: Optional[int] = None,
+    compression: str = "gzip",
+    on_error: str = "abort_statement",
+    parallel: int = 4,
+    quote_identifiers: bool = True,
+) -> Tuple[
+    bool,
+    int,
+    int,
+    Sequence[
+        Tuple[
+            str,
+            str,
+            int,
+            int,
+            int,
+            int,
+            Optional[str],
+            Optional[int],
+            Optional[int],
+            Optional[str],
+        ]
+    ],
+]:
     """Allows users to most efficiently write back a pandas DataFrame to Snowflake.
 
     It works by dumping the DataFrame into Parquet files, uploading them and finally copying their data into the table.
@@ -82,54 +110,64 @@ def write_pandas(conn: 'SnowflakeConnection',
         ingested correctly, # of chunks, # of ingested rows, and ingest's output.
     """
     if database is not None and schema is None:
-        raise ProgrammingError("Schema has to be provided to write_pandas when a database is provided")
+        raise ProgrammingError(
+            "Schema has to be provided to write_pandas when a database is provided"
+        )
     # This dictionary maps the compression algorithm to Snowflake put copy into command type
     # https://docs.snowflake.com/en/sql-reference/sql/copy-into-table.html#type-parquet
-    compression_map = {
-        'gzip': 'auto',
-        'snappy': 'snappy'
-    }
+    compression_map = {"gzip": "auto", "snappy": "snappy"}
     if compression not in compression_map.keys():
-        raise ProgrammingError("Invalid compression '{}', only acceptable values are: {}".format(
-            compression,
-            compression_map.keys()
-        ))
+        raise ProgrammingError(
+            "Invalid compression '{}', only acceptable values are: {}".format(
+                compression, compression_map.keys()
+            )
+        )
     if quote_identifiers:
-        location = ((('"' + database + '".') if database else '') +
-                    (('"' + schema + '".') if schema else '') +
-                    ('"' + table_name + '"'))
+        location = (
+            (('"' + database + '".') if database else "")
+            + (('"' + schema + '".') if schema else "")
+            + ('"' + table_name + '"')
+        )
     else:
-        location = ((database + '.' if database else '') +
-                    (schema + '.' if schema else '') +
-                    (table_name))
+        location = (
+            (database + "." if database else "")
+            + (schema + "." if schema else "")
+            + (table_name)
+        )
     if chunk_size is None:
         chunk_size = len(df)
     cursor = conn.cursor()
     stage_name = None  # Forward declaration
     while True:
         try:
-            stage_name = ''.join(random.choice(string.ascii_lowercase) for _ in range(5))
-            create_stage_sql = ('create temporary stage /* Python:snowflake.connector.pandas_tools.write_pandas() */ '
-                                '"{stage_name}"').format(stage_name=stage_name)
+            stage_name = "".join(
+                random.choice(string.ascii_lowercase) for _ in range(5)
+            )
+            create_stage_sql = (
+                "create temporary stage /* Python:snowflake.connector.pandas_tools.write_pandas() */ "
+                '"{stage_name}"'
+            ).format(stage_name=stage_name)
             logger.debug("creating stage with '{}'".format(create_stage_sql))
             cursor.execute(create_stage_sql, _is_internal=True).fetchall()
             break
         except ProgrammingError as pe:
-            if pe.msg.endswith('already exists.'):
+            if pe.msg.endswith("already exists."):
                 continue
             raise
 
     with TemporaryDirectory() as tmp_folder:
         for i, chunk in chunk_helper(df, chunk_size):
-            chunk_path = os.path.join(tmp_folder, 'file{}.txt'.format(i))
+            chunk_path = os.path.join(tmp_folder, "file{}.txt".format(i))
             # Dump chunk into parquet file
             chunk.to_parquet(chunk_path, compression=compression)
             # Upload parquet file
-            upload_sql = ('PUT /* Python:snowflake.connector.pandas_tools.write_pandas() */ '
-                          '\'file://{path}\' @"{stage_name}" PARALLEL={parallel}').format(
-                path=chunk_path.replace('\\', '\\\\').replace('\'', '\\\''),
+            upload_sql = (
+                "PUT /* Python:snowflake.connector.pandas_tools.write_pandas() */ "
+                "'file://{path}' @\"{stage_name}\" PARALLEL={parallel}"
+            ).format(
+                path=chunk_path.replace("\\", "\\\\").replace("'", "\\'"),
                 stage_name=stage_name,
-                parallel=parallel
+                parallel=parallel,
             )
             logger.debug("uploading files with '{}'".format(upload_sql))
             cursor.execute(upload_sql, _is_internal=True)
@@ -138,37 +176,78 @@ def write_pandas(conn: 'SnowflakeConnection',
     if quote_identifiers:
         columns = '"' + '","'.join(list(df.columns)) + '"'
     else:
-        columns = ','.join(list(df.columns))
+        columns = ",".join(list(df.columns))
 
     # in Snowflake, all parquet data is stored in a single column, $1, so we must select columns explicitly
     # see (https://docs.snowflake.com/en/user-guide/script-data-load-transform-parquet.html)
-    parquet_columns = '$1:' + ',$1:'.join(df.columns)
-    copy_into_sql = ('COPY INTO {location} /* Python:snowflake.connector.pandas_tools.write_pandas() */ '
-                     '({columns}) '
-                     'FROM (SELECT {parquet_columns} FROM @"{stage_name}") '
-                     'FILE_FORMAT=(TYPE=PARQUET COMPRESSION={compression}) '
-                     'PURGE=TRUE ON_ERROR={on_error}').format(
+    if quote_identifiers:
+        parquet_columns = "$1:" + ",$1:".join(f'"{c}"' for c in df.columns)
+    else:
+        parquet_columns = "$1:" + ",$1:".join(df.columns)
+    copy_into_sql = (
+        "COPY INTO {location} /* Python:snowflake.connector.pandas_tools.write_pandas() */ "
+        "({columns}) "
+        'FROM (SELECT {parquet_columns} FROM @"{stage_name}") '
+        "FILE_FORMAT=(TYPE=PARQUET COMPRESSION={compression}) "
+        "PURGE=TRUE ON_ERROR={on_error}"
+    ).format(
         location=location,
         columns=columns,
         parquet_columns=parquet_columns,
         stage_name=stage_name,
         compression=compression_map[compression],
-        on_error=on_error
+        on_error=on_error,
     )
     logger.debug("copying into with '{}'".format(copy_into_sql))
     copy_results = cursor.execute(copy_into_sql, _is_internal=True).fetchall()
     cursor.close()
-    return (all(e[1] == 'LOADED' for e in copy_results),
-            len(copy_results),
-            sum(e[3] for e in copy_results),
-            copy_results)
+    return (
+        all(e[1] == "LOADED" for e in copy_results),
+        len(copy_results),
+        sum(e[3] for e in copy_results),
+        copy_results,
+    )
 
 
-def pd_writer(table: 'pandas.io.sql.SQLTable',
-              conn: Union['sqlalchemy.engine.Engine', 'sqlalchemy.engine.Connection'],
-              keys: Iterable,
-              data_iter: Iterable,
-              quote_identifiers: bool = True) -> None:
+def make_pd_writer(
+    quote_identifiers: bool = True,
+) -> Callable[
+    [
+        "pandas.io.sql.SQLTable",
+        Union["sqlalchemy.engine.Engine", "sqlalchemy.engine.Connection"],
+        Iterable,
+        Iterable,
+    ],
+    None,
+]:
+    """This returns a pd_writer with the desired arguments.
+
+        Example usage:
+            import pandas as pd
+            from snowflake.connector.pandas_tools import pd_writer
+
+            sf_connector_version_df = pd.DataFrame([('snowflake-connector-python', '1.0')], columns=['NAME', 'NEWEST_VERSION'])
+            sf_connector_version_df.to_sql('driver_versions', engine, index=False, method=make_pd_writer())
+
+            # to use quote_identifiers=False,
+            from functools import partial
+            sf_connector_version_df.to_sql(
+                'driver_versions', engine, index=False, method=make_pd_writer(quote_identifiers=False)))
+
+    Args:
+        quote_identifiers: if True (default), the pd_writer will pass quote identifiers to Snowflake.
+            If False, the created pd_writer will not quote identifiers (and typically coerced to uppercase by Snowflake)
+    """
+    return partial(pd_writer, quote_identifiers=quote_identifiers)
+
+
+def pd_writer(
+    table: "pandas.io.sql.SQLTable",
+    conn: Union["sqlalchemy.engine.Engine", "sqlalchemy.engine.Connection"],
+    keys: Iterable,
+    data_iter: Iterable,
+    quote_identifiers: bool = True,
+) -> None:
     """This is a wrapper on top of write_pandas to make it compatible with to_sql method in pandas.
 
         Example usage:
@@ -178,10 +257,7 @@ def pd_writer(table: 'pandas.io.sql.SQLTable',
             sf_connector_version_df = pd.DataFrame([('snowflake-connector-python', '1.0')], columns=['NAME', 'NEWEST_VERSION'])
             sf_connector_version_df.to_sql('driver_versions', engine, index=False, method=pd_writer)
 
-            # to use quote_identifiers=False
-            from functools import partial
-            sf_connector_version_df.to_sql(
-                'driver_versions', engine, index=False, method=partial(pd_writer, quote_identifiers=False))
+            # to use quote_identifiers=False, see `make_pd_writer`
 
     Args:
         table: Pandas package's table object.
@@ -193,9 +269,11 @@ def pd_writer(table: 'pandas.io.sql.SQLTable',
     """
     sf_connection = conn.connection.connection
     df = pandas.DataFrame(data_iter, columns=keys)
-    write_pandas(conn=sf_connection,
-                 df=df,
-                 # Note: Our sqlalchemy connector creates tables case insensitively
-                 table_name=table.name.upper(),
-                 schema=table.schema,
-                 quote_identifiers=quote_identifiers)
+    write_pandas(
+        conn=sf_connection,
+        df=df,
+        # Note: Our sqlalchemy connector creates tables case insensitively
+        table_name=table.name.upper(),
+        schema=table.schema,
+        quote_identifiers=quote_identifiers,
+    )
