@@ -31,10 +31,15 @@ def main():
             "Dump OCSP Response cache. This tools extracts OCSP response "
             "cache file, i.e., ~/.cache/snowflake/ocsp_response_cache. "
             "Note the subject name shows up if the certificate exists in "
-            "the certs directory.")
-        print("""
+            "the certs directory."
+        )
+        print(
+            """
 Usage: {}  <ocsp response cache file> <hostname file> <cert file glob pattern>
-""".format(path.basename(sys.argv[0])))
+""".format(
+                path.basename(sys.argv[0])
+            )
+        )
         sys.exit(2)
 
     if len(sys.argv) < 4:
@@ -48,8 +53,7 @@ Usage: {}  <ocsp response cache file> <hostname file> <cert file glob pattern>
 
     hostname_file = sys.argv[2]
     cert_glob_pattern = sys.argv[3]
-    dump_ocsp_response_cache(
-        ocsp_response_cache_file, hostname_file, cert_glob_pattern)
+    dump_ocsp_response_cache(ocsp_response_cache_file, hostname_file, cert_glob_pattern)
 
 
 def raise_old_cache_exception(current_time, created_on, name, serial_number):
@@ -58,32 +62,39 @@ def raise_old_cache_exception(current_time, created_on, name, serial_number):
         "should be newer than {}: "
         "name: {}, serial_number: {}, "
         "current_time: {}, created_on: {}".format(
-            strftime(SFOCSP.OUTPUT_TIMESTAMP_FORMAT, gmtime(
-                current_time - OCSP_CACHE_SERVER_INTERVAL)),
-            name, serial_number,
             strftime(
-                SFOCSP.OUTPUT_TIMESTAMP_FORMAT, gmtime(current_time)),
-            strftime(
-                SFOCSP.OUTPUT_TIMESTAMP_FORMAT, gmtime(created_on))))
+                SFOCSP.OUTPUT_TIMESTAMP_FORMAT,
+                gmtime(current_time - OCSP_CACHE_SERVER_INTERVAL),
+            ),
+            name,
+            serial_number,
+            strftime(SFOCSP.OUTPUT_TIMESTAMP_FORMAT, gmtime(current_time)),
+            strftime(SFOCSP.OUTPUT_TIMESTAMP_FORMAT, gmtime(created_on)),
+        )
+    )
 
 
 def raise_outdated_validity_exception(
-        current_time, name, serial_number, this_update, next_update):
-    raise Exception("ERROR: OCSP response cache include "
-                    "outdated data: "
-                    "name: {}, serial_number: {}, "
-                    "current_time: {}, this_update: {}, "
-                    "next_update: {}".format(
-        name, serial_number,
-        strftime(
-            SFOCSP.OUTPUT_TIMESTAMP_FORMAT, gmtime(current_time)),
-        this_update.strftime(
-            SFOCSP.OUTPUT_TIMESTAMP_FORMAT),
-        next_update.strftime(
-            SFOCSP.OUTPUT_TIMESTAMP_FORMAT)))
+    current_time, name, serial_number, this_update, next_update
+):
+    raise Exception(
+        "ERROR: OCSP response cache include "
+        "outdated data: "
+        "name: {}, serial_number: {}, "
+        "current_time: {}, this_update: {}, "
+        "next_update: {}".format(
+            name,
+            serial_number,
+            strftime(SFOCSP.OUTPUT_TIMESTAMP_FORMAT, gmtime(current_time)),
+            this_update.strftime(SFOCSP.OUTPUT_TIMESTAMP_FORMAT),
+            next_update.strftime(SFOCSP.OUTPUT_TIMESTAMP_FORMAT),
+        )
+    )
 
 
-def dump_ocsp_response_cache(ocsp_response_cache_file, hostname_file, cert_glob_pattern):
+def dump_ocsp_response_cache(
+    ocsp_response_cache_file, hostname_file, cert_glob_pattern
+):
     """Dump OCSP response cache contents.
 
     Show the subject name as well if the subject is included in the certificate files.
@@ -93,8 +104,7 @@ def dump_ocsp_response_cache(ocsp_response_cache_file, hostname_file, cert_glob_
     s_to_n1 = _serial_to_name(sfocsp, cert_glob_pattern)
     s_to_n.update(s_to_n1)
 
-    SFOCSP.OCSP_CACHE.read_ocsp_response_cache_file(
-        sfocsp, ocsp_response_cache_file)
+    SFOCSP.OCSP_CACHE.read_ocsp_response_cache_file(sfocsp, ocsp_response_cache_file)
 
     def custom_key(k):
         # third element is Serial Number for the subject
@@ -112,43 +122,43 @@ def dump_ocsp_response_cache(ocsp_response_cache_file, hostname_file, cert_glob_
         else:
             name = "Unknown"
         output[json_key] = {
-            'serial_number': format(serial_number, 'd'),
-            'name': name,
+            "serial_number": format(serial_number, "d"),
+            "name": name,
         }
         value = ocsp_validation_cache[hkey]
         cache = value[1]
         ocsp_response = ocsp.OCSPResponse.load(cache)
         basic_ocsp_response = ocsp_response.basic_ocsp_response
 
-        tbs_response_data = basic_ocsp_response['tbs_response_data']
+        tbs_response_data = basic_ocsp_response["tbs_response_data"]
 
         current_time = int(time())
-        for single_response in tbs_response_data['responses']:
+        for single_response in tbs_response_data["responses"]:
             created_on = int(value[0])
-            produce_at = tbs_response_data['produced_at'].native
-            this_update = single_response['this_update'].native
-            next_update = single_response['next_update'].native
+            produce_at = tbs_response_data["produced_at"].native
+            this_update = single_response["this_update"].native
+            next_update = single_response["next_update"].native
             if current_time - OCSP_CACHE_SERVER_INTERVAL > created_on:
-                raise_old_cache_exception(current_time, created_on, name,
-                                          serial_number)
+                raise_old_cache_exception(current_time, created_on, name, serial_number)
 
             next_update_utc = (
-                    next_update.replace(
-                        tzinfo=None) - ZERO_EPOCH).total_seconds()
+                next_update.replace(tzinfo=None) - ZERO_EPOCH
+            ).total_seconds()
             this_update_utc = (
-                    this_update.replace(
-                        tzinfo=None) - ZERO_EPOCH).total_seconds()
+                this_update.replace(tzinfo=None) - ZERO_EPOCH
+            ).total_seconds()
 
-            if current_time > next_update_utc or \
-                    current_time < this_update_utc:
+            if current_time > next_update_utc or current_time < this_update_utc:
                 raise_outdated_validity_exception(
-                    current_time, name, serial_number, this_update, next_update)
+                    current_time, name, serial_number, this_update, next_update
+                )
 
-            output[json_key]['created_on'] = strftime(
-                SFOCSP.OUTPUT_TIMESTAMP_FORMAT, gmtime(created_on))
-            output[json_key]['produce_at'] = str(produce_at)
-            output[json_key]['this_update'] = str(this_update)
-            output[json_key]['next_update'] = str(next_update)
+            output[json_key]["created_on"] = strftime(
+                SFOCSP.OUTPUT_TIMESTAMP_FORMAT, gmtime(created_on)
+            )
+            output[json_key]["produce_at"] = str(produce_at)
+            output[json_key]["this_update"] = str(this_update)
+            output[json_key]["next_update"] = str(next_update)
     print(json.dumps(output))
 
 
@@ -168,7 +178,7 @@ def _serial_to_name(sfocsp, cert_glob_pattern):
 
 def _fetch_certs(hostname_file):
     with open(hostname_file) as f:
-        hostnames = f.read().split('\n')
+        hostnames = f.read().split("\n")
 
     map_serial_to_name = {}
     for h in hostnames:
@@ -183,5 +193,5 @@ def _fetch_certs(hostname_file):
     return map_serial_to_name
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     main()
